<template>
	<el-tabs v-model="activeName" class="demo-tabs min-w-[38rem] flex-column" @tab-click="handleClick">
		<el-tab-pane class="h-full" label="Chart" name="first">
			<!-- <el-select class="flex-0 w-36" v-model="selectChartType" @change="selectChartTypeChange">
				<el-option
					v-for="item in Object.keys(chartTypeMapName)"
					:key="item"
					:value="parseInt(item)"
					:label="chartTypeMapName[item]"
				></el-option>
			</el-select> -->
			<div class="flex-auto">
				<div ref="chartRef" class="h-full"></div>
			</div>
		</el-tab-pane>
		<el-tab-pane class="h-full" label="Data" name="second">
			<el-table :data="data.values" style="width: 100%">
				<el-table-column v-for="(item, index) in data?.names" :label="item" :key="index">
					<template #default="scope">
						{{ scope.row[index] }}
					</template>
				</el-table-column>
			</el-table>
		</el-tab-pane>
	</el-tabs>
</template>
<script lang="ts" setup>
import * as echarts from 'echarts';
import type { TabsPaneContext } from 'element-plus';
import type { PropType } from 'vue';
import { onMounted, ref } from 'vue';
import { ChartTypeEnum, chartTypeMapEchart, chartTypeMapName } from '../types';
import type { RecordSetValues } from '/@/api/ai/chat';
import { dateRegex } from '/@/utils/toolsValidate';
import { timeDataOptionToContent } from '../common';
const activeName = ref('first');
const chartRef = ref<HTMLDivElement>(null);
const selectChartType = ref<ChartTypeEnum>(ChartTypeEnum.Line);

const props = defineProps({
	data: {
		type: Object as PropType<RecordSetValues>,
	},
});

const selectChartTypeChange = () => {
	drawChart();
};

const handleClick = (tab: TabsPaneContext, event: Event) => {};

let chartInstance: echarts.ECharts = null;

const getXType = (xData?: any[]) => {
	const xValue = xData?.[0];
	if (xValue == null) return 'value';
	if (typeof xValue === 'number') {
		return 'value';
	} else if (typeof xValue === 'string') {
		const isValidDate = dateRegex.test(xValue);
		return isValidDate ? 'time' : 'category';
	} else {
		throw '图表x轴数据类型异常';
	}
};

const drawChart = () => {
	const xData = props.data.values?.map((item) => item[0]);
	const xType = getXType(xData);
	chartInstance.setOption({
		grid: {
			// bottom: 120,
			right: '15%',
			bottom: '5%',
		},
		tooltip: {
			show: true,
			trigger: 'axis',
		},
		toolbox: {
			show: true,
			feature: {
				dataZoom: {
					yAxisIndex: 'none',
				},
				myBar: {
					title: '转化为柱状图',
					show: true,
					icon: 'path://M580.8 228.8h-136v500.8h136V228.8z m-40 460.8h-56V268.8h56v420.8zM788.8 420.8h-136v308.8h136V420.8z m-40 268.8h-56V460.8h56v228.8zM372.8 326.4h-136v401.6h136V326.4z m-40 363.2h-56V366.4h56v323.2zM208 788.8h608v40H208z',
					onclick: () => {
						chartInstance.setOption({
							series: {
								data: props.data.values,
								type: 'bar',
							},
						});
					},
				},

				myScatter: {
					title: '转化为散点图',
					show: true,
					icon: 'path://M445.7 609.8c0 19.4 10.3 37.3 27.1 46.9 16.8 9.7 37.4 9.7 54.2 0 16.8-9.7 27.1-27.6 27.1-46.9 0-29.9-24.3-54.2-54.2-54.2s-54.2 24.3-54.2 54.2z m0 0M179.2 613.8c-42.2 0-76.5 34.3-76.5 76.5s34.3 76.5 76.5 76.5 76.5-34.3 76.5-76.5-34.3-76.5-76.5-76.5z m0 0M144.9 401.1c0 29 23.5 52.5 52.5 52.5s52.5-23.5 52.5-52.5-23.5-52.5-52.5-52.5-52.5 23.5-52.5 52.5z m0 0M598.7 404c0 42.2 34.3 76.5 76.5 76.5 42.3 0 76.5-34.3 76.5-76.5 0-42.3-34.3-76.5-76.5-76.5-42.3 0-76.5 34.3-76.5 76.5z m0 0M849.3 169.2c-42.2 0-76.5 34.3-76.5 76.5s34.3 76.5 76.5 76.5 76.5-34.3 76.5-76.5-34.3-76.5-76.5-76.5z m0 0M261.6 583.1c0 13.2 7.1 25.5 18.5 32.1 11.5 6.6 25.6 6.6 37.1 0s18.5-18.9 18.5-32.1c0-20.5-16.6-37.1-37.1-37.1-20.4 0.1-37 16.7-37 37.1z m0 0M276.8 425.1c0 42.3 34.3 76.5 76.5 76.5 42.3 0 76.5-34.3 76.5-76.5s-34.3-76.5-76.5-76.5-76.5 34.3-76.5 76.5z m0 0M445.7 421.4c0 18.5 9.9 35.5 25.8 44.8 16 9.2 35.7 9.2 51.7 0s25.8-26.3 25.8-44.8c0-28.5-23.1-51.7-51.7-51.7-28.5 0-51.6 23.2-51.6 51.7z m0 0M398.2 208.8c0 42.3 34.3 76.5 76.5 76.5s76.5-34.3 76.5-76.5c0-42.3-34.3-76.5-76.5-76.5s-76.5 34.3-76.5 76.5z m0 0M693.7 599.2c0 42.3 34.3 76.5 76.5 76.5s76.5-34.3 76.5-76.5-34.3-76.5-76.5-76.5c-42.3 0-76.5 34.3-76.5 76.5z m0 0M62.1 828.9H959v60.7H62.1z',
					onclick: () => {
						chartInstance.setOption({
							data: props.data.values,
							type: 'scatter',
						});
					},
				},
				myRestore: {
					title: '还原',
					show: true,
					icon: 'path://M909.637 478.524c-15.444-189.946-167.065-345.049-356.655-364.38-99.805-10.176-193.011 16.474-267.901 67.887l18.467-68.842c5.725-21.337-6.933-43.274-28.27-48.998s-43.274 6.934-48.998 28.271l-41.455 154.536c-5.724 21.337 6.933 43.273 28.271 48.998l154.536 41.455c21.337 5.724 43.273-6.934 48.998-28.271 5.724-21.337-6.934-43.274-28.271-48.998l-54.194-14.538c58.917-39.301 131.457-59.686 208.999-52.061 147.885 14.543 268.327 132.461 285.589 280.053 23.02 196.82-133.879 363.973-327.45 358.219-135.107-4.017-252.98-96.111-294.938-224.602-17.513-53.632-18.92-105.027-9.92-152.849 3.188-16.946-4.238-34.086-19.172-42.707l-0.049-0.028c-23.737-13.705-54.358-0.164-59.404 26.777-7.724 41.233-9.128 84.686-2.965 129.403 25.571 185.535 181.03 330.336 367.878 343.176C727.656 927.857 929.6 724.049 909.637 478.524z',
					onclick: () => {
						chartInstance.setOption({
							data: props.data.values,
							type: 'line',
						});
					},
				},
				dataView: {
					readOnly: true,
					optionToContent: timeDataOptionToContent,

				},
				saveAsImage: {},
			},
		},

		title: {
			text: props.data.title,
			left: 'center',
		},
		xAxis: {
			name: props.data?.names[0],
			type: xType,
		},
		yAxis: {
			name: props.data?.names[1],
			type: 'value',
		},
		series: [
			{
				data: props.data.values,
				type: chartTypeMapEchart[selectChartType.value],
			},
		],
		dataZoom: {
			type: 'inside',
		},
	});
};

onMounted(() => {
	setTimeout(() => {
		const parent = chartRef.value.parentElement;
		if (!parent) {
		}
		const parentBound = parent.getBoundingClientRect();
		chartInstance = echarts.init(chartRef.value, undefined, {
			width: parentBound.width,
			height: parentBound.height,
		});

		drawChart();
	}, 300);
});
</script>

<style scoped lang="scss">
.el-tabs {
	:deep(.el-tabs__header) {
		flex: 0 0 auto;
	}
	:deep(.el-tabs__content) {
		flex: 1;
		.el-tab-pane {
			display: flex;
			flex-direction: column;
			min-height: 24rem;
		}
	}
}
</style>
